/******************************************************************************
 * The MIT License
 *
 * Copyright (c) 2010 Perry Hung.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *****************************************************************************/

/**
 *  @brief basic stm32 flash setup routines
 */
#include "libmaple.h"
#include "usb_hardware.h"

#ifndef _FLASH_H_
#define _FLASH_H_

#define FLASH_WAIT_STATE_0              0x0
#define FLASH_WAIT_STATE_1              0x1
#define FLASH_WAIT_STATE_2              0x2

#define FLASH_ACR     FLASH + 0x00
#define FLASH_KEYR    FLASH + 0x04
#define FLASH_OPTKEYR FLASH + 0x08
#define FLASH_SR      FLASH + 0x0C
#define FLASH_CR      FLASH + 0x10
#define FLASH_AR      FLASH + 0x14
#define FLASH_OBR     FLASH + 0x1C
#define FLASH_WRPR    FLASH + 0x20

#define FLASH_KEY1     0x45670123
#define FLASH_KEY2     0xCDEF89AB
#define FLASH_RDPRT    0x00A5
#define FLASH_SR_BSY   0x01
#define FLASH_CR_PER   0x02
#define FLASH_CR_PG    0x01
#define FLASH_CR_START 0x40

#ifdef __cplusplus
extern "C"{
#endif

void flash_enable_prefetch(void);
void flash_set_latency(uint32 wait_states);
void setupFLASH(void);
uint8 flashErasePage(uint32 pageAddr);
uint8 flashErasePages(uint32 pageAddr, uint16 n);
uint8 flashWriteWord(uint32 addr, uint32 word);
void flashLock(void);
void flashUnlock(void);
	
	
	
	
	
#ifdef __cplusplus
}
#endif

#endif


